From: Vojtech Pavlik <vojtech@suse.cz>

The i8042 driver prints the PS/2 Controller irqs incorrectly - for the classic
IRQ 1 and IRQ 12 case, it is:

     PNP: PS/2 Controller [PNP0303:PS2K] at 0x60,0x64 irq 112 

Reported-by: Alexey Dobriyan <adobriyan@gmail.com>
Reported-by: Rene Herman <rene.herman@keyaccess.nl>
Signed-off-by: Vojtech Pavlik <vojtech@suse.cz>

Index: dmitry/drivers/input/serio/i8042-x86ia64io.h
===================================================================
--- dmitry.orig/drivers/input/serio/i8042-x86ia64io.h	2005-07-05 16:23:15.000000000 +0200
+++ dmitry/drivers/input/serio/i8042-x86ia64io.h	2005-07-05 16:28:32.000000000 +0200
@@ -281,12 +281,12 @@
 	}
 
 	if (!i8042_pnp_kbd_irq) {
-		printk(KERN_WARNING "PNP: PS/2 controller doesn't have KBD irq; using default %#x\n", i8042_kbd_irq);
+		printk(KERN_WARNING "PNP: PS/2 controller doesn't have KBD irq; using default %d\n", i8042_kbd_irq);
 		i8042_pnp_kbd_irq = i8042_kbd_irq;
 	}
 
 	if (!i8042_pnp_aux_irq) {
-		printk(KERN_WARNING "PNP: PS/2 controller doesn't have AUX irq; using default %#x\n", i8042_aux_irq);
+		printk(KERN_WARNING "PNP: PS/2 controller doesn't have AUX irq; using default %d\n", i8042_aux_irq);
 		i8042_pnp_aux_irq = i8042_aux_irq;
 	}
 
@@ -300,10 +300,14 @@
 	i8042_kbd_irq = i8042_pnp_kbd_irq;
 	i8042_aux_irq = i8042_pnp_aux_irq;
 
-	printk(KERN_INFO "PNP: PS/2 Controller [%s%s%s] at %#x,%#x irq %d%s%d\n",
-		i8042_pnp_kbd_name, (result_kbd > 0 && result_aux > 0) ? "," : "", i8042_pnp_aux_name,
-		i8042_data_reg, i8042_command_reg, i8042_kbd_irq,
-		(result_aux > 0) ? "," : "", i8042_aux_irq);
+	printk(KERN_INFO "PNP: PS/2 Controller [%s%s%s] at %#x,%#x irq %d",
+		i8042_pnp_kbd_name,
+		(result_kbd > 0 && result_aux > 0) ? "," : "",
+		i8042_pnp_aux_name,
+		i8042_data_reg, i8042_command_reg, i8042_kbd_irq);
+	if (!i8042_noaux)
+		printk(",%d", i8042_aux_irq);
+	printk("\n");
 
 	return 0;
 }
